/********************************************************************
* KITCLOCK.C
*
* A software kitchen clock, see README.TXT
*
* (C) 2003 www.wickenhaeuser.com
*
* The T0 timer's input FRQ is the XTAL/12. The reload divisor divides
* this by 250, so the interrupt runs at XTAL/3000. For a 11.0592 MHz
* crystal, the interrupt is called 3686.4 times per sec (4000 times for 
* a 12 MHz crystal, but for this only baudrates up to 4800 are possible).
*
********************************************************************/

#include <stdio.h>

#include <reg51.h>
#include <irq52.h>
#include "T6963.h"


near unsigned char cnt_down=50; 		// Internal counter for the IRQ
near char user_cnt;		// The user's counter
near unsigned int i;

unsigned char bit  pflag;

// We don't want to have debug info in the interrupt, additionaly only bank 0 is allowed
#pragma option -g0 cpu51 -b0


// Install a vector to the function for Timer 0
IRQ_VECTOR(timer0int,TIMER0)

void timer0int (void)
interrupt
{

 TH0 = 135;		//Reload default value for Timer0
  if(!--cnt_down)
  {	
	cnt_down=80;	//Reload default value for 1sec pause (50*20ms=1sec)
	
	//P0_B0^=1;	// Toggle LED (at P3.5 on almost all Wickenhaeuser Boards)
	user_cnt++;
  }
}


//#pragma option -g cpu51 -b0- // Restore debug info level to default and enable temporaries



// *** MAIN ***
void main(void)
{
   EA   = 0;	// Disable all Interrupts (not necessary, but a good habbit)

  // Init Timer0 (assume UART initialised by startup code)
  TMOD = 1;  // TMOD Timer 0: 16 bit counter
  TH0 = 135;	 // FRQ is XTAL/3000 : 11.0592 MHz: 3.6864 kHz
  TCON = 16;
  ET0  = 1;	 // Enable timer interrupt
  TR0  = 1;	 // Start timer
  EA   = 1;	// Global enable all enabled Interrupts
  user_cnt=0x55;

 _wait_ms(20);		//Wake-Up Time for 20ms
 lcd_init();
 
 lcd_send_cmd(0xB0);// Auto Write Mode an (Auto Inkrement)
 //gotoXY (1,1); /*
 lcd_send_data(0x01);   //first low then high byte  
 lcd_send_data(0x06);
 lcd_send_cmd(0x24); 
 
 while (1)
  {
	_wait_ms(20);
	
	lcd_send_data_am(user_cnt);
	/*
	gotoXY (0,1);
	lcd_send_data_am(user_cnt);
	gotoXY (0,2);
	lcd_send_data_am(user_cnt); 
	gotoXY (0,3);
	lcd_send_data_am(user_cnt); */
  }
}

// END
